summaryrefslogtreecommitdiffstats
path: root/gtk2/kgtk2.c
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2/kgtk2.c')
-rw-r--r--gtk2/kgtk2.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/gtk2/kgtk2.c b/gtk2/kgtk2.c
index d0457c5..84941dd 100644
--- a/gtk2/kgtk2.c
+++ b/gtk2/kgtk2.c
@@ -149,7 +149,7 @@ static const gchar *getAppName(const gchar *app)
const gchar *a=app ? app : kgtk_get_app_name(getpid());
gchar *slash;
/* Was the cmdline app java? if so, try to use its parent name - just in case
its run from a shell script, etc. - e.g. as eclipse does */
if(a && 0==strcmp(a, "java"))
a=kgtk_get_app_name(getppid());
@@ -249,7 +249,7 @@ static gboolean sendMessage(GtkWidget *widget, Operation op, GSList **res, gchar
if(widget->parent)
{
#ifdef KGTK_DEBUG
- printf("KGTK::Dialog has a parent!\n");
+ printf("KGTK::Dialog has a tqparent!\n");
#endif
xid=GDK_WINDOW_XID(gtk_widget_get_toplevel(widget->parent));
}
@@ -543,7 +543,7 @@ typedef struct _GtkFilePath GtkFilePath;
typedef struct _GtkFileSystemModel GtkFileSystemModel;
struct _GtkFileFilter
{
- GtkObject parent_instance;
+ GtkObject tqparent_instance;
gchar *name;
GSList *rules;
@@ -632,7 +632,7 @@ RowType;
static GtkWidget *
kgtk_file_chooser_dialog_new_valist (const gchar *title,
- GtkWindow *parent,
+ GtkWindow *tqparent,
GtkFileChooserAction action,
const gchar *backend,
const gchar *first_button_text,
@@ -648,8 +648,8 @@ kgtk_file_chooser_dialog_new_valist (const gchar *title,
"file-system-backend", backend,
NULL);
- if (parent)
- gtk_window_set_transient_for (GTK_WINDOW (result), parent);
+ if (tqparent)
+ gtk_window_set_transient_for (GTK_WINDOW (result), tqparent);
while (button_text)
{
@@ -764,7 +764,7 @@ static void freeHash(void *hash)
}
}
-/* Some Gtk apps have filter pattern *.[Pp][Nn][Gg] - wherease Qt/KDE prefer *.png */
+/* Some Gtk apps have filter pattern *.[Pp][Nn][Gg] - wherease TQt/KDE prefer *.png */
#define MAX_PATTERN_LEN 64
static gchar *modifyFilter(const char *filter)
{
@@ -1737,7 +1737,7 @@ void g_signal_stop_emission_by_name(gpointer instance, const gchar *detailed_sig
#endif
}
-GtkWidget * gtk_file_chooser_dialog_new(const gchar *title, GtkWindow *parent,
+GtkWidget * gtk_file_chooser_dialog_new(const gchar *title, GtkWindow *tqparent,
GtkFileChooserAction action, const gchar *first_button_text,
...)
{
@@ -1748,7 +1748,7 @@ GtkWidget * gtk_file_chooser_dialog_new(const gchar *title, GtkWindow *parent,
va_list varargs;
va_start(varargs, first_button_text);
- dlg=kgtk_file_chooser_dialog_new_valist(title, parent, action, NULL, first_button_text, varargs);
+ dlg=kgtk_file_chooser_dialog_new_valist(title, tqparent, action, NULL, first_button_text, varargs);
va_end(varargs);
#ifdef KGTK_DEBUG
@@ -149,7 +149,7 @@ static const gchar *getAppName(const gchar *app)
const gchar *a=app ? app : kgtk_get_app_name(getpid());
gchar *slash;
- /* Was the cmdline app java? if so, try to use its parent name - just in case
+ /* Was the cmdline app java? if so, try to use its tqparent name - just in case
its run from a shell script, etc. - e.g. as eclipse does */
if(a && 0==strcmp(a, "java"))